==> haskell-monoid-subclasses-1.2.5.1-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.2.5.1
visibility:           public
id:                   monoid-subclasses-1.2.5.1-sZtPOJaZ0S6evtjY5CeiJ
key:                  monoid-subclasses-1.2.5.1-sZtPOJaZ0S6evtjY5CeiJ
license:              BSD-3-Clause
copyright:            (c) 2013-2024 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  c91aaef8d74bce6768aa7638216da9ce
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.PrefixMemory Data.Monoid.Instances.Stateful
    Data.Monoid.LCM Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.2.5.1-sZtPOJaZ0S6evtjY5CeiJ
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    commutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
    containers-0.6.5.1 primes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
    text-1.2.5.0 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-1.2.6-30.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monoid-subclasses
version:              1.2.6
visibility:           public
id:                   monoid-subclasses-1.2.6-8ousr21el3cFapOtJYAzhK
key:                  monoid-subclasses-1.2.6-8ousr21el3cFapOtJYAzhK
license:              BSD-3-Clause
copyright:            (c) 2013-2024 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  6097a137cc0fe3e1b5a2208c9bb49de3
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.PrefixMemory Data.Monoid.Instances.Stateful
    Data.Monoid.LCM Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monoid-subclasses-1.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monoid-subclasses-1.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monoid-subclasses-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.2.6-8ousr21el3cFapOtJYAzhK
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    commutative-semigroups-0.2.0.2-KKbxYpGvMjb9AEMnknsNP1
    containers-0.6.7 primes-0.2.1.0-LmLNpOWl018Fc2AFLcapwU text-2.0.2
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
